% $Id: gen_random_lps.m 107 2006-11-23 01:52:47Z mpf $
%
% Create a series of dual degenerate LPs using Gonzaga's random LP
% generator.  Each LP is written into an AMPL data file.
%
% REFERENCE
% M. P. Friedlander
% Exact regularization of Linear Programs
% Dept of Computer Science Tech Rept TR-2005-31
% December 2005

n = 1000;
m = 100;

opts.make_figure =  0;
opts.option      =  2;
opts.xopt_l      =  1;
opts.xopt_u      =  100;
opts.sopt_l      =  1;
opts.sopt_u      =  100;
opts.m           =  m;
opts.n           =  n;
opts.a_dens      =  .01;

% The randomly generated LPs all have simple lower bounds:
% 0 <= x <= Inf.
xL = zeros(n,1);
xU = inf*ones(n,1);

% Max dimensions of primal and dual optimal faces.
pMax = n - m - 1;
dMax = m - 1;

% Generate dual degenerate LPs:
for fraction = [0  20  40  60  80  100]

    opts.pdim = floor(pMax * fraction / 100);
    opts.ddim = 0;
    
    [A, b, c, xopt, sopt, p, rankAB, x0] = genlp( opts );
    
    fname = ['random' '-p' num2str(fraction) '-d0.dat'];
    matlab2ampl( fname, fname, A, b, c, xL, xU, x0 );
end
    
