function matlab2ampl(outfile, problem_name, A, b, c, xL, xU, x0)
% matlab2ampl( outfile, problem_name, A, b, c, xL, xU )
%
% Write the linear program
%
%  minimize  c' x
%
%  subj to   A * x = b,  xL <= x <= xU
%
% to an Ampl data file.

[m, n] = size(A);
nnzA   = nnz(A);
[ir, jc, aVal] = find(A);
ir   = reshape(ir,   nnzA, 1);
jc   = reshape(jc,   nnzA, 1);
aVal = reshape(aVal, nnzA, 1);

me   = (1:m)';
ne   = (1:n)';

fid  = fopen( outfile, 'w' );

% Problem name.
fprintf(fid, 'param problem_name := "%s";\n', problem_name );

% Problem dimensions.
fprintf(fid, 'param n   := %i;\n', n);
fprintf(fid, 'param m   := %i;\n', m);
fprintf(fid, 'param nnz := %i;\n', nnzA);

% Sparsity pattern and data of constraint matrix.
fprintf(fid, 'param: NODES: A:=\n');
fprintf(fid, '%i  %i  %22.15e\n', [ir  jc  aVal]');
fprintf(fid, ';\n');

% Right-hand side.
fprintf(fid, 'param b :=\n');
fprintf(fid, '%i   %22.15e\n', [me b]');
fprintf(fid, ';\n');

% Objective row.
fprintf(fid, 'param c :=\n');
fprintf(fid, '%i   %22.15e\n', [ne c]');
fprintf(fid, ';\n');

% Lower bounds on x.
% Only write values that are finite.
finite = find(isfinite(xL));
fprintf(fid, 'param xL default -Infinity :=\n');
fprintf(fid, '%i   %22.15e\n', [finite xL(finite)]');
fprintf(fid, ';\n');

% Upper bounds on x.
finite = find(isfinite(xU));
fprintf(fid, 'param xU default +Infinity :=\n');
fprintf(fid, '%i   %22.15e\n', [finite xU(finite)]');
fprintf(fid, ';\n');

% Starting point.
if isempty(x0)
   % Relax.
else
  fprintf(fid, 'param x0 :=\n');
  fprintf(fid, '%i   %22.15e\n', [ne x0]');
  fprintf(fid, ';\n');
end

fclose(fid);