function rundimacs(problems)
% Find exact regularizations of the SOCPs in the DIMACS test suite.
% Make sure to set the variable 'top_dir' to the top-level
% directory of your DIMACS7 distribution.
%
% Authors:
% Michael P. Friedlander        Paul Tseng
% Univ of British Columbia      Univ of Washington
% mpf@cs.ubc.ca                 tseng@math.washington.edu
% 
% $Revision: 106 $ $Date: 2006-11-22 17:52:19 -0800 (Wed, 22 Nov 2006) $

% Location to the DIMACS problems.
  top_dir = '/Users/mpf/local/dimacs7/';

% The DIMACS collection.
  dimacs = {
      'ANTENNA/nb'
      'ANTENNA/nb_L1'
      'ANTENNA/nb_L2'
      'ANTENNA/nb_L2_bessel'
%     'BISECT/biomedP'            % Need to generate from script.
%     'BISECT/bm1'                % Selection prob out of mem.
      'COPOS/copo14'
      'COPOS/copo23'
%     'COPOS/copo68'              % Orig problem out of mem.
%     'FAP/fap09'                 % ..
%     'FAP/fap25'
%     'FAP/fap36'                 % Need to generate from script.
      'FILTER/filter48_socp'
%     'FILTER/filtinf1'           % Infeasible
      'FILTER/minphase'
%     'HAMMING/hamming_7_5_6'     % Selection prob out of mem.
%     'HAMMING/hamming_8_3_4'     % Original  prob out of mem.
%     'HAMMING/hamming_9_5_6'     % ..
%     'HAMMING/hamming_9_8'       % ..
%     'HAMMING/hamming_10_2'      % ..
%     'HAMMING/hamming_11_2'      % ..
      'HINF/hinf12'
      'HINF/hinf13'               % Duality gap = +inf for all problems.
      'NQL/nql30'
      'NQL/nql60'
      'NQL/nql180'
      'NQL/nql30old'
      'NQL/nql60old'
      'NQL/nql180old'
      'QSSP/qssp30'
      'QSSP/qssp60'
      'QSSP/qssp180'
      'SCHED/sched_50_50_orig'
      'SCHED/sched_50_50_scaled'
      'SCHED/sched_100_50_orig'
      'SCHED/sched_100_50_scaled'
      'SCHED/sched_100_100_orig'
      'SCHED/sched_100_100_scaled'
      'SCHED/sched_200_100_orig'
      'SCHED/sched_200_100_scaled'
%     'TORUS/torusg3-8'           % Original prob out of mem.
%     'TORUS/torusg3-15'          % ..
%     'TORUS/toruspm3-8-50'       % ..
%     'TORUS/toruspm3-15-50'      % ..
      'TRUSS/truss5'
      'TRUSS/truss8'
      };
  
% Replace the Unix fileseparator '/' with this system's correct one.
  for i = 1:length(dimacs);
      dimacs(i) = regexprep(dimacs(i),'\/',filesep);
  end

% Loop over each DIMACS problem.
  fid = 1; %  = fopen('dimacs.out','w');        % The summary file.
  if isempty(problems), problems = 1:length(dimacs); end
  for i = problems

    clear A At b c K
    problem = dimacs{i};
    
    fullpath = [top_dir problem];
    [pathstr, name, ext, versn] = fileparts( fullpath );

  % Open the Sedumi log file and load the problem.
    fidsub  = fopen([name '.out'], 'w');
    load(fullpath);
    
  % The test problems define either A or A', and sometimes b,c as row
  % vectors or scalars.  Ugh!
    if exist('At','var'), A = At'; end
    if size(b,1) == 1, b = b'; end
    if size(c,1) == 1
       if isscalar(c)
          c = repmat(c,size(A,2),1);
       else
          c = c';
       end
    end
    
  % Compute the exact L1 regularization.    
    mu = exactregl1(name,A,b,c,K,fid,fidsub);

  % Close the Sedumi log file.
    fclose(fidsub);
    
  end
% fclose(fid);  % Close the summary file.
